﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows.Threading;
using System.Windows;
using Infragistics.Controls;
using Infragistics.Controls.Charts;
using System.Linq;

namespace ChartPlayground
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window {
        private Random rand = new Random( );
        private DispatcherTimer timer = new DispatcherTimer();
        private double current = 0.0;
        private int flipCounter = 0;
        private List<ObservableCollection<DataPoint>> list = new List<ObservableCollection<DataPoint>>();
        ObservableCollection<DataPoint> axisList = new ObservableCollection<DataPoint>();
        

        public MainWindow()
        {
            InitializeComponent();
            this.Loaded += OnWindowLoaded;

            /*timer.Interval = new TimeSpan(0, 0, 0, 0, 500);
            timer.Tick += Timer_Tick;
            timer.Start();*/
        }

        private void Timer_Tick( object sender, EventArgs e ) {
            current = rand.Next( 0, 10 );

            var index = ( ( flipCounter = ++flipCounter % 3 ) == 0 ) ? 0 : 1;
            var lastPoint = ( list[ index ] )[ list[ index ].Count - 1 ];
            DataPoint dp = new DataPoint(  )
                               {
                                   X = index == 0 ? lastPoint.X + 2 : lastPoint.X + 1, 
                                   Y = current
                               };
            
            list[ index ].Add( dp );

            DataPoint lastAxisPoint = axisList[ axisList.Count - 1 ];
            if ( lastAxisPoint.X < dp.X ) {
                for ( var i = lastAxisPoint.X + 1; i < dp.X; i++ ) {
                    axisList.Add( new DataPoint { X = i } );
                }
                axisList.Add( dp );
            }
        }

        private void OnWindowLoaded( object sender, RoutedEventArgs e ) {
            var points = new ObservableCollection<DataPoint>
                             {
                                 new DataPoint( ) {X = 0, Y = 1},
                                 new DataPoint( ) {X = 1, Y = 5},
                                 new DataPoint( ) {X = 2, Y = 3},
                                 new DataPoint( ) {X = 3, Y = 7},
                                 new DataPoint( ) {X = 4, Y = 6},
                                 new DataPoint( ) {X = 5, Y = 2},
                                 new DataPoint( ) {X = 6, Y = 9}
                             };

            var points2 = new ObservableCollection<DataPoint>
                              {
                                  new DataPoint( ) {X = 0, Y = 3},
                                  new DataPoint( ) {X = 1, Y = 6},
                                  new DataPoint( ) {X = 2, Y = 8},
                                  new DataPoint( ) {X = 3, Y = 3},
                                  new DataPoint( ) {X = 4, Y = 5}
                                 

                              };
            list.Add( points );
            list.Add( points2 );
            axisList = new ObservableCollection<DataPoint>
                             {
                                 new DataPoint( ) {X = 0, Y = 0},
                                 new DataPoint( ) {X = 1, Y = 0},
                                 new DataPoint( ) {X = 2, Y = 0},
                                 new DataPoint( ) {X = 3, Y = 0},
                                 new DataPoint( ) {X = 4, Y = 0},
                                 new DataPoint( ) {X = 5, Y = 0},
                                 new DataPoint( ) {X = 6, Y = 0},
                                  new DataPoint( ) {X = 7, Y = 0},
                                   new DataPoint( ) {X = 8, Y = 0}
                             };



          

            /* Here is where you can see the behavior I describe.  When the ItemsSource is 'points', the X axis updates
             * when the longer collection (points) updates.  You can see as well that whether points or points2 recieves
             * an update from the timer event the chart is updated.  The X axis does not change until the points collection
             * does.
             * 
             * However if you change ItemsSource to 'points2', the X axis is limited to the points from the second
             * collection.  I figure this is expected behavior.  However the axis still only updates when 'points2' is
             * updated and you cannot see the additional data added to the 'points' collection.
             */
            var xAxis = new CategoryXAxis { Label = "{X}", ItemsSource=axisList};
           

            var yAxis = new NumericYAxis(  );

            var lineSeries = new LineSeries
                                 {
                                     MarkerType = MarkerType.None,
                                     Thickness = 5,
                                     ItemsSource = points,
                                     ValueMemberPath = "Y",
                                     XAxis = xAxis,
                                     YAxis = yAxis,
                                     Title = "Series 1"
                                 };

            var lineSeries2 = new LineSeries
                                  {
                                      MarkerType = MarkerType.None,
                                      Thickness = 5,
                                      ItemsSource = points2,
                                      ValueMemberPath = "Y",
                                      XAxis = xAxis,
                                      YAxis = yAxis,
                                      Title = "Series 2"
                                  };

            var legend = new Legend {Content = "Common Legend", Margin = new Thickness(10) };
            XamDock.SetEdge( legend, DockEdge.InsideRight );

            Chart1.Legend = legend;

            Dock1.Children.Add( legend );
            Chart1.Axes.Add( xAxis );
            Chart1.Axes.Add( yAxis );
            Chart1.Series.Add( lineSeries );
            Chart1.Series.Add( lineSeries2 );

            // Moved Code
            timer.Interval = new TimeSpan(0, 0, 0, 0, 500);
            timer.Tick += Timer_Tick;
            timer.Start();
        }
    }

    class DataPoint {
        public double X { get; set; }
        public double Y { get; set; }
    }
}
